@@ -17,6 +17,10 @@ from cognite.client.data_classes.files import (
     FileMetadataFilter,
     FileMetadataList,
     FileMetadataUpdate,
+    GeoLocation,
+    GeoLocationFilter,
+    Geometry,
+    GeometryFilter,
 )
 from cognite.client.data_classes.iam import (
     APIKey,
@@ -28,6 +32,13 @@ from cognite.client.data_classes.iam import (
     ServiceAccount,
     ServiceAccountList,
 )
+from cognite.client.data_classes.labels import (
+    Label,
+    LabelDefinition,
+    LabelDefinitionFilter,
+    LabelDefinitionList,
+    LabelFilter,
+)
 from cognite.client.data_classes.login import LoginStatus
 from cognite.client.data_classes.raw import Database, DatabaseList, Row, RowList, Table, TableList
 from cognite.client.data_classes.relationships import Relationship, RelationshipFilter, RelationshipList
@@ -40,7 +51,7 @@ from cognite.client.data_classes.sequences import (
     SequenceList,
     SequenceUpdate,
 )
-from cognite.client.data_classes.shared import TimestampRange, AggregateResult, AggregateUniqueValuesResult
+from cognite.client.data_classes.shared import AggregateResult, AggregateUniqueValuesResult, TimestampRange
 from cognite.client.data_classes.three_d import (
     BoundingBox3D,
     RevisionCameraProperties,
@@ -62,10 +73,3 @@ from cognite.client.data_classes.time_series import (
     TimeSeriesList,
     TimeSeriesUpdate,
 )
-from cognite.client.data_classes.labels import (
-    LabelDefinition,
-    LabelDefinitionFilter,
-    LabelDefinitionList,
-    Label,
-    LabelFilter,
-)
